==> cosmpy-0.1.3.tar.gz: cosmpy-0.1.3/tests/vulture_whitelist.py <==
# -*- coding: utf-8 -*-
# ------------------------------------------------------------------------------
#
#   Copyright 2018-2021 Fetch.AI Limited
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
# ------------------------------------------------------------------------------

# pylint: skip-file

_.Simulate  # unused method (./clients/signing_cosmwasm_client_test.py:144)
_.GetTx  # unused method (./clients/signing_cosmwasm_client_test.py:148)
_.GetTxsEvent  # unused method (./clients/signing_cosmwasm_client_test.py:157)
_.auth_client  # unused attribute (./clients/signing_cosmwasm_client_test.py:191)
_.raw_log  # unused attribute (./clients/signing_cosmwasm_client_test.py:467)
_.raw_log  # unused attribute (./clients/signing_cosmwasm_client_test.py:490)
_.status_code  # unused attribute (./common/test_rest_client.py:48)
_.status_code  # unused attribute (./common/test_rest_client.py:75)
_.status_code  # unused attribute (./common/test_rest_client.py:103)
_.status_code  # unused attribute (./common/test_rest_client.py:140)
_.last_request  # unused attribute (./helpers.py:36)
_.last_used_params  # unused attribute (./helpers.py:37)
_.last_request  # unused attribute (./helpers.py:49)
_.last_used_params  # unused attribute (./helpers.py:50)
_.last_request  # unused attribute (./helpers.py:57)
my_import  # unused function (./tx/tests.py:67)
TxSign  # unused class (./tx/tests.py:101)
_.body_bytes  # unused attribute (./tx/tests.py:148)
_.auth_info_bytes  # unused attribute (./tx/tests.py:149)
_.denom  # unused attribute (./tx/tests.py:232)
_.mode  # unused attribute (./tx/tests.py:247)

==> cosmpy-0.4.1.tar.gz: cosmpy-0.4.1/tests/vulture_whitelist.py <==
# -*- coding: utf-8 -*-
# ------------------------------------------------------------------------------
#
#   Copyright 2018-2021 Fetch.AI Limited
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
# ------------------------------------------------------------------------------

# pylint: skip-file

_.Simulate  # unused method (./clients/signing_cosmwasm_client_test.py:144)
_.GetTx  # unused method (./clients/signing_cosmwasm_client_test.py:148)
_.GetTxsEvent  # unused method (./clients/signing_cosmwasm_client_test.py:157)
_.auth_client  # unused attribute (./clients/signing_cosmwasm_client_test.py:191)
_.raw_log  # unused attribute (./clients/signing_cosmwasm_client_test.py:467)
_.raw_log  # unused attribute (./clients/signing_cosmwasm_client_test.py:490)
_.status_code  # unused attribute (./common/test_rest_client.py:48)
_.status_code  # unused attribute (./common/test_rest_client.py:75)
_.status_code  # unused attribute (./common/test_rest_client.py:103)
_.status_code  # unused attribute (./common/test_rest_client.py:140)
_.last_request  # unused attribute (./tx_helpers.py:36)
_.last_used_params  # unused attribute (./tx_helpers.py:37)
_.last_request  # unused attribute (./tx_helpers.py:49)
_.last_used_params  # unused attribute (./tx_helpers.py:50)
_.last_request  # unused attribute (./tx_helpers.py:57)
my_import  # unused function (./tx/tests.py:67)
TxSign  # unused class (./tx/tests.py:101)
_.body_bytes  # unused attribute (./tx/tests.py:148)
_.auth_info_bytes  # unused attribute (./tx/tests.py:149)
_.denom  # unused attribute (./tx/tests.py:232)
_.mode  # unused attribute (./tx/tests.py:247)
